@@ -2,7 +2,7 @@ import uuid
 from django.contrib.auth import get_user_model
 from django.conf import settings
 from django.db import models
-from django.db.models.signals import pre_save, post_save
+from django.db.models.signals import pre_save, post_save, post_delete
 from django.dispatch import receiver
 from djangoldp.models import Model
 from django.utils.text import slugify
@@ -227,3 +227,31 @@ def pre_save_circle_relation(sender, instance, **kwargs):
 def create_community_profile(instance, created, **kwargs):
     if not Model.is_external(instance):
         CommunityProfile.objects.get_or_create(community=instance)
+
+@receiver(post_save, sender=Community)
+def create_community_member_admin(instance, created, **kwargs):
+    if not Model.is_external(instance):
+        if created:
+            CommunityMember.objects.get_or_create(community=instance, user=getattr(instance, "modification_user", None), is_admin=True)
+        else:
+            if instance.members.count() == 1 and not instance.members.first().is_admin:
+                CommunityMember.objects.filter(community=instance).update(is_admin=True)
+            # Community must have an admin. It'll be you so.
+            if instance.members.count() == 0:
+                CommunityMember.objects.get_or_create(community=instance, user=getattr(instance, "modification_user", None), is_admin=True)
+
+@receiver(post_save, sender=CommunityMember)
+def admin_if_last_member(instance, **kwargs):
+    if not Model.is_external(instance.community):
+        if instance.community.members.count() < 2 and not instance.is_admin:
+            instance.is_admin = True
+            instance.save()
+
+@receiver(post_delete, sender=CommunityMember)
+def admin_if_last_member(instance, **kwargs):
+    if not Model.is_external(instance.community):
+        if instance.community.members.count() == 1 and not instance.community.members.first().is_admin:
+            CommunityMember.objects.filter(community=instance.community).update(is_admin=True)
+        # Community must have an admin. It'll be you so.
+        if instance.community.members.count() == 0:
+            CommunityMember.objects.get_or_create(community=instance.community, user=getattr(instance, "modification_user", None), is_admin=True)
