@@ -125,6 +125,23 @@ class CommunityJobPermissions(LDPPermissions):
 class CommunityMembersPermissions(CommunityPermissions):
     filter_backends = []
 
+    def get_object_permissions(self, request, view, obj):
+        perms = super().get_object_permissions(request, view, obj)
+
+        user = request.user
+
+        if is_authenticated_user(user):
+            perms = perms.union({'view'})
+            if obj.user == user:
+                if obj.community.allow_self_registration == True or obj.is_admin:
+                    perms = perms.union({'add', 'delete'})
+
+            elif obj.community.members.filter(user=user).count() > 0:
+                if obj.community.members.filter(user=user).get().is_admin:
+                    perms = perms.union({'add', 'delete', 'change'})
+
+        return perms
+
     def get_container_permissions(self, request, view, obj=None):
         perms = set({'view'})
         if obj is None:
