@@ -112,6 +112,33 @@ class PermissionsTestCase(APITestCase):
         self.assertEqual(len(response.data['permissions']), 1)
     '''
 
+    def test_get_communities_is_member(self):
+        self.setUpLoggedInUser(is_superuser=False)
+        community = self._get_random_community()
+        me = self._get_community_member(user=self.user, community=community, is_admin=False)
+
+        response = self.client.get('/communities/')
+        self.assertEqual(response.status_code, 200)
+        communities = response.data['ldp:contains']
+        self.assertEqual(len(communities), 1)
+        members_permissions = communities[0]['members']['permissions']
+        self.assertNotIn({'mode': {'@type': 'add'}}, members_permissions)
+        self.assertEqual(len(members_permissions), 1)
+
+    def test_get_communities_is_admin(self):
+        self.setUpLoggedInUser(is_superuser=False)
+        community = self._get_random_community()
+        me = self._get_community_member(user=self.user, community=community, is_admin=True)
+
+        response = self.client.get('/communities/')
+        self.assertEqual(response.status_code, 200)
+        communities = response.data['ldp:contains']
+        self.assertEqual(len(communities), 1)
+        members_permissions = communities[0]['members']['permissions']
+        self.assertIn({'mode': {'@type': 'add'}}, members_permissions)
+        self.assertIn({'mode': {'@type': 'view'}}, members_permissions)
+        self.assertEqual(len(members_permissions), 2)
+
     # only community admins can do any operation on community members
     def test_add_community_member_is_admin(self):
         self.setUpLoggedInUser(is_superuser=False)
